@@ -3,6 +3,7 @@ from glapi.connection import GitlabConnection
 from glapi.epic import GitlabEpic
 from glapi.issue import GitlabIssue
 from glapi.project import GitlabProject
+from glapi.user import GitlabUser
 
 class GitlabGroup:
     """
@@ -24,13 +25,14 @@ class GitlabGroup:
         self.group = group if group else (self.connection.query("groups/%s" % id)["data"] if id and token and version else None)
         self.id = self.group["id"] if self.group else None
 
-    def extract_epics(self, date_start: str = None, date_end: str = None) -> list:
+    def extract_epics(self, date_start: str = None, date_end: str = None, get_notes: bool = False) -> list:
         """
         Extract group-specific epic data.
 
         Args:
             date_end (string): iso 8601 date value
             date_start (string): iso 8601 date value
+            get_notes (boolean): TRUE if notes should be pulled
 
         Returns:
             A list of GitlabEpic classes where each represents a GtiLab Epic.
@@ -53,17 +55,19 @@ class GitlabGroup:
             )
 
             # generate GitlabEpic
-            result = [GitlabEpic(epic=d) for d in epics]
+            result = [GitlabEpic(epic=d, get_notes=get_notes) for d in epics]
 
         return result
 
-    def extract_issues(self, scope: str = "all", date_start: str = None, date_end: str = None) -> list:
+    def extract_issues(self, scope: str = "all", date_start: str = None, date_end: str = None, get_notes: bool = False, get_links: bool = False) -> list:
         """
         Extract group-specific epic data.
 
         Args:
             date_end (string): iso 8601 date value
             date_start (string): iso 8601 date value
+            get_links (boolean): TRUE if links should be pulled
+            get_notes (boolean): TRUE if notes should be pulled
             scope (enum): all | assigned_to_me | created_by_me
 
         Returns:
@@ -88,7 +92,7 @@ class GitlabGroup:
             )
 
             # generate GitlabIssue
-            result = [GitlabIssue(issue=d) for d in issues]
+            result = [GitlabIssue(issue=d, get_links=get_links, get_notes=get_notes) for d in issues]
 
         return result
 
@@ -125,3 +129,26 @@ class GitlabGroup:
             result = [GitlabProject(project=d) for d in projects]
 
         return result
+
+    def extract_users(self) -> list:
+        """
+        Extract group-specific user data.
+
+        Returns:
+            A list of GitlabUser classes where each represents a GtiLab User.
+        """
+
+        result = None
+
+        # check connection params
+        if self.id and self.connection.token and self.connection.version:
+
+            # query api
+            users = self.connection.paginate(
+                endpoint="groups/%s/members" % self.id
+            )
+
+            # generate GitlabUser
+            result = [GitlabUser(user=d) for d in users]
+
+        return result
